
/*
 * Bootstrap Protocol (BOOTP).  RFC951 and RFC1048.
 *
 * $Header: bootp.h,v 1.2 93/08/14 19:10:26 leres Exp $
 *
 *
 * This file specifies the "implementation-independent" BOOTP protocol
 * information which is common to both client and server.
 *
 *
 * Copyright 1988 by Carnegie Mellon.
 *
 * Permission to use, copy, modify, and distribute this program for any
 * purpose and without fee is hereby granted, provided that this copyright
 * and permission notice appear on all copies and supporting documentation,
 * the name of Carnegie Mellon not be used in advertising or publicity
 * pertaining to distribution of the program without specific prior
 * permission, and notice be given in supporting documentation that copying
 * and distribution is by permission of Carnegie Mellon and Stanford
 * University.  Carnegie Mellon makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 */


struct bootp {
	u_char	bp_op;			/* packet opcode type */
	u_char	bp_htype;		/* hardware addr type */
	u_char	bp_hlen;		/* hardware addr length */
	u_char	bp_hops;		/* gateway hops */
	u_long	bp_xid;			/* transaction ID */
	u_short	bp_secs;		/* seconds since boot began */
	u_short	bp_unused;
	u_long	bp_ciaddr;		/* client IP address */
	u_long	bp_yiaddr;		/* 'your' IP address */
	u_long	bp_siaddr;		/* server IP address */
	u_long	bp_giaddr;		/* gateway IP address */
	u_char	bp_chaddr[16];		/* client hardware address */
	u_char	bp_sname[64];		/* server host name */
	u_char	bp_file[128];		/* boot file name */
	u_char	bp_vend[64];		/* vendor-specific area */
};

/*
 * UDP port numbers, server and client.
 */
#define	IPPORT_BOOTPS		67
#define	IPPORT_BOOTPC		68

#define BOOTREPLY		2
#define BOOTREQUEST		1


/*
 * Vendor magic cookie (v_magic) for CMU
 */
#define VM_CMU		"CMU"

/*
 * Vendor magic cookie (v_magic) for RFC1048
 */
#define VM_RFC1048	{ 99, 130, 83, 99 }



/*
 * RFC1048 tag values used to specify what information is being supplied in
 * the vendor field of the packet.
 */

#define TAG_PAD			((u_char)   0)
#define TAG_SUBNET_MASK		((u_char)   1)
#define TAG_TIME_OFFSET		((u_char)   2)
#define TAG_GATEWAY		((u_char)   3)
#define TAG_TIME_SERVER		((u_char)   4)
#define TAG_NAME_SERVER		((u_char)   5)
#define TAG_DOMAIN_SERVER	((u_char)   6)
#define TAG_LOG_SERVER		((u_char)   7)
#define TAG_COOKIE_SERVER	((u_char)   8)
#define TAG_LPR_SERVER		((u_char)   9)
#define TAG_IMPRESS_SERVER	((u_char)  10)
#define TAG_RLP_SERVER		((u_char)  11)
#define TAG_HOSTNAME		((u_char)  12)
#define TAG_BOOTSIZE		((u_char)  13)
#define TAG_END			((u_char) 255)



/*
 * "vendor" data permitted for CMU bootp clients.
 */

struct cmu_vend {
	u_char	v_magic[4];		/* magic number */
	u_long	v_flags;		/* flags/opcodes, etc. */
	u_long 	v_smask;		/* Subnet mask */
	u_long 	v_dgate;		/* Default gateway */
	u_long	v_dns1, v_dns2;		/* Domain name servers */
	u_long	v_ins1, v_ins2;		/* IEN-116 name servers */
	u_long	v_ts1, v_ts2;		/* Time servers */
	u_char	v_unused[25];		/* currently unused */
};


/* v_flags values */
#define VF_SMASK	1	/* Subnet mask field contains valid data */
